Ma: Matern autocovariance

View source: R/time_series_model.R

MaR Documentation

Matern autocovariance

Description

Computes the Matern correlation at lags x for smoothness alpha. This is used internally to build the full autocovariance vector.

Usage

Ma(x, alpha)

Arguments

x

Numeric vector of lags (non-negative).

alpha

Smoothness parameter in (1/2, 10).

Value

Numeric vector of correlations for each lag in x.


gmwmx2 documentation built on June 10, 2026, 5:06 p.m.