download_all_stations_ngl: Download all stations name and location from the Nevada...

View source: R/ngl.R

download_all_stations_nglR Documentation

Download all stations name and location from the Nevada Geodetic Laboratory

Description

Download all stations name and location from the Nevada Geodetic Laboratory

Usage

download_all_stations_ngl(verbose = FALSE)

Arguments

verbose

A boolean that controls the level of detail in the output of the wget command used to load data. Default is FALSE.

Value

Return a data.frame with all stations name, latitude, longitude and heights.

Examples

df_all_stations <- download_all_stations_ngl()
head(df_all_stations)


gmwmx2 documentation built on June 10, 2026, 5:06 p.m.