download_estimated_velocities_ngl: Download estimated velocities using the MIDAS estimator...

View source: R/ngl.R

download_estimated_velocities_nglR Documentation

Download estimated velocities using the MIDAS estimator provided by the Nevada Geodetic Laboratory for all stations.

Description

Download estimated velocities using the MIDAS estimator provided by the Nevada Geodetic Laboratory for all stations.

Usage

download_estimated_velocities_ngl(verbose = FALSE)

Arguments

verbose

A boolean that controls the level of detail in the output of the wget command used to load data. Default is FALSE.

Value

Return a data.frame with all stations name, information about the time series for each station, estimated velocities and estimated standard deviation of the estimated velocities.

Examples

df_estimated_velocities <- download_estimated_velocities_ngl()
head(df_estimated_velocities)

gmwmx2 documentation built on June 10, 2026, 5:06 p.m.