| gmwmx2_plot_colors | R Documentation |
Editable default palette used by the plotting methods for generated time series. When more colors are needed, the palette is expanded with interpolation.
gmwmx2_plot_colors
A character vector of hex colors.
.gmwmx2_get_plot_colors
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.