| loss_fn_gmwm | R Documentation |
Computes the weighted squared error between empirical wavelet variance and theoretical wavelet variance implied by a model and parameter vector.
loss_fn_gmwm(theta, model, n, prep, wv_obj, omega = NULL)
theta |
Real-valued parameter vector. |
model |
A |
n |
Length of autocovariance to compute. |
prep |
Output from |
wv_obj |
A |
omega |
Optional weighting matrix. If |
Scalar objective value.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.