loss_fn_gmwmx_no_missing: Loss function for GMWMX without missing value

View source: R/loss_functions_gmwmx.R

loss_fn_gmwmx_no_missingR Documentation

Loss function for GMWMX without missing value

Description

Computes the weighted squared error between empirical wavelet variance and theoretical wavelet variance implied by a model and parameter vector.

Usage

loss_fn_gmwmx_no_missing(
  theta,
  model,
  n,
  prep,
  wv_obj,
  quantities_D,
  omega = NULL
)

Arguments

theta

Real-valued parameter vector.

model

A time_series_model or sum_model.

n

Length of autocovariance to compute.

prep

Output from prepare_optim_layout.

wv_obj

A wv::wvar object.

omega

Optional weighting matrix. If NULL, uses inverse CI width.

Value

Scalar objective value.


gmwmx2 documentation built on June 10, 2026, 5:06 p.m.