| print.gmwmx2_fit | R Documentation |
gmwmx2_fit objectDisplays a table of regression coefficients with standard errors and summarizes the fitted stochastic model with estimated parameters.
## S3 method for class 'gmwmx2_fit'
print(x, digits = 4, ...)
x |
A |
digits |
Significant digits to display. |
... |
Passed to print methods. |
The input object, invisibly.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.