rw: Random walk process ('time_series_model')

View source: R/time_series_model.R

rwR Documentation

Random walk process (time_series_model)

Description

Constructs a time_series_model for a random walk with innovation variance sigma2. The autocovariance returned is the mean of the diagonal and super-diagonals of the covariance matrix. The model is X_t = X_{t-1} + \varepsilon_t, \; \varepsilon_t \stackrel{\text{i.i.d.}}{\sim} N(0, \sigma^2).

Usage

rw(sigma2 = NULL)

Arguments

sigma2

Innovation variance (> 0).

Value

A time_series_model object.

Examples

mod <- rw(sigma2 = 1)
mod

gmwmx2 documentation built on June 10, 2026, 5:06 p.m.