Learn R Programming

gmwmx2 (version 0.0.5)

sum_model: Sum of stochastic models (internal)

Description

Creates a composite model representing a sum of independent time_series_model components. This is an internal constructor used by the + methods.

Usage

sum_model(models)

Value

A sum_model object.

Arguments

models

A list of time_series_model objects.

Examples

Run this code
mod <- pl(kappa = 0.5, sigma2 = 2) + wn(sigma2 = 1)
print(mod)

Run the code above in your browser using DataLab