View source: R/time_series_model.R
| Ma | R Documentation |
Computes the Matern correlation at lags x for smoothness alpha.
This is used internally to build the full autocovariance vector.
Ma(x, alpha)
x |
Numeric vector of lags (non-negative). |
alpha |
Smoothness parameter in (1/2, 10). |
Numeric vector of correlations for each lag in x.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.