Learn R Programming

gmwmx2 (version 0.0.5)

Ma: Matern autocovariance

Description

Computes the Matern correlation at lags x for smoothness alpha. This is used internally to build the full autocovariance vector.

Usage

Ma(x, alpha)

Value

Numeric vector of correlations for each lag in x.

Arguments

x

Numeric vector of lags (non-negative).

alpha

Smoothness parameter in (1/2, 10).