Learn R Programming

gmwmx2 (version 0.0.5)

download_estimated_velocities_ngl: Download estimated velocities using the MIDAS estimator provided by the Nevada Geodetic Laboratory for all stations.

Description

Download estimated velocities using the MIDAS estimator provided by the Nevada Geodetic Laboratory for all stations.

Usage

download_estimated_velocities_ngl(verbose = FALSE)

Value

Return a data.frame with all stations name, information about the time series for each station, estimated velocities and estimated standard deviation of the estimated velocities.

Arguments

verbose

A boolean that controls the level of detail in the output of the wget command used to load data. Default is FALSE.

Examples

Run this code
df_estimated_velocities <- download_estimated_velocities_ngl()
head(df_estimated_velocities)

Run the code above in your browser using DataLab