download_estimated_velocities_ngl: Download estimated velocities using the MIDAS estimator provided by the Nevada Geodetic Laboratory for all stations.
Description
Download estimated velocities using the MIDAS estimator provided by the Nevada Geodetic Laboratory for all stations.
Return a data.frame with all stations name, information about the time series for each station, estimated velocities and estimated standard deviation of the estimated velocities.
Arguments
verbose
A boolean that controls the level of detail in the output of the wget command used to load data. Default is FALSE.