A list of class gnss_ts_ngl that contains three data.frame: The data.frame
df_position which contains the position time series extracted from the .tenv3 file available from the Nevada Geodetic Laboratory, the
data.frame
df_equipment_software_changes which specify the equipment or software changes for that stations and the data.frame
df_earthquakes that specify the earthquakes associated with that station.