View source: R/get_autocovariance.R
| get_autocovariance | R Documentation |
If theta is NULL, uses domain parameters stored in the model.
If theta is provided, it is treated as unconstrained parameters in
real space and mapped to the domain via the model's transformation.
get_autocovariance(object, n, theta = NULL, prep = NULL, ...)
object |
A |
n |
Length of autocovariance vector. |
theta |
Optional real-valued parameter vector for optimization. |
prep |
Optional output from |
... |
Passed to methods. |
Numeric vector of autocovariances of length n.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.