Learn R Programming

gmwmx2 (version 0.0.5)

get_autocovariance: Compute autocovariance for a model (internal)

Description

If theta is NULL, uses domain parameters stored in the model. If theta is provided, it is treated as unconstrained parameters in real space and mapped to the domain via the model's transformation.

Usage

get_autocovariance(object, n, theta = NULL, prep = NULL, ...)

Value

Numeric vector of autocovariances of length n.

Arguments

object

A time_series_model or sum_model.

n

Length of autocovariance vector.

theta

Optional real-valued parameter vector for optimization.

prep

Optional output from prepare_optim_layout (required for sum models with theta).

...

Passed to methods.