If theta is NULL, uses domain parameters stored in the model.
If theta is provided, it is treated as unconstrained parameters in
real space and mapped to the domain via the model's transformation.
get_autocovariance(object, n, theta = NULL, prep = NULL, ...)Numeric vector of autocovariances of length n.
A time_series_model or sum_model.
Length of autocovariance vector.
Optional real-valued parameter vector for optimization.
Optional output from prepare_optim_layout (required for sum models with theta).
Passed to methods.