Learn R Programming

gmwmx2 (version 0.0.5)

gmwmx2_plot_colors: Plot colors for generated time series

Description

Editable default palette used by the plotting methods for generated time series. When more colors are needed, the palette is expanded with interpolation.

Usage

gmwmx2_plot_colors

Arguments

Format

A character vector of hex colors.

See Also

.gmwmx2_get_plot_colors