Computes the weighted squared error between empirical wavelet variance and theoretical wavelet variance implied by a model and parameter vector.
loss_fn_gmwm(theta, model, n, prep, wv_obj, omega = NULL)Scalar objective value.
Real-valued parameter vector.
A time_series_model or sum_model.
Length of autocovariance to compute.
Output from prepare_optim_layout.
A wv::wvar object.
Optional weighting matrix. If NULL, uses inverse CI width.