matern: Matern process ('time_series_model')

View source: R/time_series_model.R

maternR Documentation

Matern process (time_series_model)

Description

Constructs a time_series_model for a Matern covariance process with variance sigma2, range lambda, and smoothness alpha. The autocovariance is \gamma(h) = \mathrm{cov}(X_t, X_{t+h}) = \frac{2 \sigma^2}{\Gamma(\alpha-1 / 2) 2^{\alpha-1 / 2}}|\lambda h|^{\alpha-1 / 2} \mathcal{K}_{|\alpha-1 / 2|}(| \lambda h|) where \mathcal{K}_\omega(x) is the modified Bessel function of the second kind of order \omega.

Usage

matern(sigma2 = NULL, lambda = NULL, alpha = NULL)

Arguments

sigma2

Marginal variance (> 0).

lambda

Range/scale parameter (> 0).

alpha

Smoothness parameter in (1/2, 10).

Value

A time_series_model object.

References

Lilly JM, Sykulski AM, Early JJ, Olhede SC (2017). "Fractional Brownian motion, the Matérn process, and stochastic modeling of turbulent dispersion." Nonlinear Processes in Geophysics, 24(3), 481-514.

Examples

mod <- matern(sigma2 = 1, lambda = 0.2, alpha = 1.0)
mod

gmwmx2 documentation built on June 10, 2026, 5:06 p.m.