Displays a table of regression coefficients with standard errors and summarizes the fitted stochastic model with estimated parameters.

# S3 method for class 'gmwmx2_fit'
print(x, digits = 4, ...)

Arguments

x

A gmwmx2_fit object.

digits

Significant digits to display.

...

Passed to print methods.

Value

The input object, invisibly.