gmwmx2_fit
R/gmwmx2.R
print.gmwmx2_fit.Rd
Displays a table of regression coefficients with standard errors and summarizes the fitted stochastic model with estimated parameters.
# S3 method for class 'gmwmx2_fit' print(x, digits = 4, ...)
A gmwmx2_fit object.
Significant digits to display.
Passed to print methods.
The input object, invisibly.