Learn R Programming

gmwmx2 (version 0.0.5)

print.gmwmx2_fit: Print method for a gmwmx2_fit object

Description

Displays a table of regression coefficients with standard errors and summarizes the fitted stochastic model with estimated parameters.

Usage

# S3 method for gmwmx2_fit
print(x, digits = 4, ...)

Value

The input object, invisibly.

Arguments

x

A gmwmx2_fit object.

digits

Significant digits to display.

...

Passed to print methods.