Displays regression coefficients with standard errors and confidence intervals, along with the fitted stochastic and missingness models.

# S3 method for class 'gmwmx2_fit_gnss_ts_ngl'
print(x, digits = 4, ...)

Arguments

x

A gmwmx2_fit_gnss_ts_ngl object.

digits

Significant digits to display.

...

Passed to print methods.

Value

The input object, invisibly.