gmwmx2_fit_gnss_ts_ngl
R/gmwmx2.R
print.gmwmx2_fit_gnss_ts_ngl.Rd
Displays regression coefficients with standard errors and confidence intervals, along with the fitted stochastic and missingness models.
# S3 method for class 'gmwmx2_fit_gnss_ts_ngl' print(x, digits = 4, ...)
A gmwmx2_fit_gnss_ts_ngl object.
Significant digits to display.
Passed to print methods.
The input object, invisibly.