Learn R Programming

gmwmx2 (version 0.0.5)

rw: Random walk process (time_series_model)

Description

Constructs a time_series_model for a random walk with innovation variance sigma2. The autocovariance returned is the mean of the diagonal and super-diagonals of the covariance matrix. The model is \(X_t = X_{t-1} + \varepsilon_t, \; \varepsilon_t \stackrel{\text{i.i.d.}}{\sim} N(0, \sigma^2)\).

Usage

rw(sigma2 = NULL)

Value

A time_series_model object.

Arguments

sigma2

Innovation variance (> 0).

Examples

Run this code
mod <- rw(sigma2 = 1)
mod

Run the code above in your browser using DataLab