powered by
Creates a composite model representing a sum of independent time_series_model components. This is an internal constructor used by the + methods.
time_series_model
+
sum_model(models)
A sum_model object.
sum_model
A list of time_series_model objects.
mod <- pl(kappa = 0.5, sigma2 = 2) + wn(sigma2 = 1) print(mod)
Run the code above in your browser using DataLab