Extract estimated parameters from a fit_gnss_ts_ngl

# S3 method for class 'fit_gnss_ts_ngl'
summary(object, scale_parameters = FALSE, ...)

Arguments

object

A fit_gnss_ts_ngl object.

scale_parameters

A boolean indicating whether or not to scale estimated parameters so that the returned estimated trend is provided in m/year instead of m/day. Default is FALSE.

...

Additional parameters.

Examples

x <- download_station_ngl("P820")
fit1 <- gmwmx2(x, n_seasonal = 2, component = "N", stochastic_model = "wn + pl")
summary(fit1)
#> Summary of Estimated Model
#> -------------------------------------------------------------
#> Functional parameters
#> -------------------------------------------------------------
#> Parameter                  Estimate  Std_Deviation  95% CI Lower  95% CI Upper
#> -------------------------------------------------------------
#> Intercept                0.74675532   0.00002219   0.74671183   0.74679882
#> Trend                   -0.00000721   0.00000003  -0.00000726  -0.00000716
#> Sin (Annual)            -0.00274753   0.00002846  -0.00280331  -0.00269176
#> Cos (Annual)            -0.00277174   0.00002821  -0.00282702  -0.00271646
#> Sin (Semi-Annual)        0.00087112   0.00002811   0.00081602   0.00092621
#> Cos (Semi-Annual)       -0.00059133   0.00002807  -0.00064634  -0.00053632
#> Jump: MJD 60649         -0.00005855   0.00013204  -0.00031734   0.00020024
#> Earthquake: MJD 60649    0.00054964   0.00027413   0.00001236   0.00108692
#> -------------------------------------------------------------
#> Stochastic parameters
#> -------------------------------------------------------------
#>  White Noise Variance  :     0.00000241
#>  Stationary powerlaw Spectral index:     0.99999630
#>  Stationary powerlaw Variance:     0.00000000
#> -------------------------------------------------------------
#> Missingness parameters
#> -------------------------------------------------------------
#>  P(Z_{i+1} = 0 | Z_{i} = 1): 0.00064893
#>  P(Z_{i+1} = 1 | Z_{i} = 0): 0.10000000
#>  \hat{E[Z]}: 0.99355255
#> -------------------------------------------------------------
#> Running time: 0.29 seconds
#> -------------------------------------------------------------
summary(fit1, scale_parameters = TRUE)
#> Summary of Estimated Model
#> -------------------------------------------------------------
#> Functional parameters
#> -------------------------------------------------------------
#> Parameter                  Estimate  Std_Deviation  95% CI Lower  95% CI Upper
#> -------------------------------------------------------------
#> Intercept              272.75238146   0.00810577 272.73649444 272.76826847
#> Trend                   -0.00263366   0.00001012  -0.00265349  -0.00261383
#> Sin (Annual)            -1.00353660   0.01039388  -1.02390823  -0.98316497
#> Cos (Annual)            -1.01237815   0.01030228  -1.03257024  -0.99218605
#> Sin (Semi-Annual)        0.31817543   0.01026675   0.29805298   0.33829789
#> Cos (Semi-Annual)       -0.21598412   0.01025188  -0.23607744  -0.19589080
#> Jump: MJD 60649         -0.02138502   0.04822759  -0.11590936   0.07313931
#> Earthquake: MJD 60649    0.20075663   0.10012471   0.00451580   0.39699745
#> -------------------------------------------------------------
#> Stochastic parameters
#> -------------------------------------------------------------
#>  White Noise Variance  :     0.00000241
#>  Stationary powerlaw Spectral index:     0.99999630
#>  Stationary powerlaw Variance:     0.00000000
#> -------------------------------------------------------------
#> Missingness parameters
#> -------------------------------------------------------------
#>  P(Z_{i+1} = 0 | Z_{i} = 1): 0.00064893
#>  P(Z_{i+1} = 1 | Z_{i} = 0): 0.10000000
#>  \hat{E[Z]}: 0.99355255
#> -------------------------------------------------------------
#> Running time: 0.29 seconds
#> -------------------------------------------------------------
fit2 <- gmwmx2(x, n_seasonal = 2, component = "N", stochastic_model = "wn + fl")
summary(fit2)
#> Summary of Estimated Model
#> -------------------------------------------------------------
#> Functional parameters
#> -------------------------------------------------------------
#> Parameter                  Estimate  Std_Deviation  95% CI Lower  95% CI Upper
#> -------------------------------------------------------------
#> Intercept                0.74675532   0.00074723   0.74529077   0.74821987
#> Trend                   -0.00000721   0.00000053  -0.00000824  -0.00000618
#> Sin (Annual)            -0.00274753   0.00017444  -0.00308943  -0.00240563
#> Cos (Annual)            -0.00277174   0.00017559  -0.00311588  -0.00242760
#> Sin (Semi-Annual)        0.00087112   0.00012511   0.00062591   0.00111633
#> Cos (Semi-Annual)       -0.00059133   0.00012246  -0.00083136  -0.00035131
#> Jump: MJD 60649         -0.00005855   0.00116660  -0.00234505   0.00222795
#> Earthquake: MJD 60649    0.00054964   0.00225461  -0.00386932   0.00496860
#> -------------------------------------------------------------
#> Stochastic parameters
#> -------------------------------------------------------------
#>  White Noise Variance  :     0.00000056
#>  Flicker Noise Variance:     0.00000080
#> -------------------------------------------------------------
#> Missingness parameters
#> -------------------------------------------------------------
#>  P(Z_{i+1} = 0 | Z_{i} = 1): 0.00064893
#>  P(Z_{i+1} = 1 | Z_{i} = 0): 0.10000000
#>  \hat{E[Z]}: 0.99355255
#> -------------------------------------------------------------
#> Running time: 1.14 seconds
#> -------------------------------------------------------------